==> ZenTaoPMS-biz11.1-zbox_arm64.tar.gz: zbox/include/php/main/build-defs.h <==
/*
   +----------------------------------------------------------------------+
   | Copyright (c) The PHP Group                                          |
   +----------------------------------------------------------------------+
   | This source file is subject to version 3.01 of the PHP license,      |
   | that is bundled with this package in the file LICENSE, and is        |
   | available through the world-wide-web at the following url:           |
   | https://www.php.net/license/3_01.txt                                 |
   | If you did not receive a copy of the PHP license and are unable to   |
   | obtain it through the world-wide-web, please send a note to          |
   | license@php.net so we can mail you a copy immediately.               |
   +----------------------------------------------------------------------+
   | Author: Stig Sæther Bakken <ssb@php.net>                             |
   +----------------------------------------------------------------------+
*/

#define CONFIGURE_COMMAND " './configure'  '--build=aarch64-linux-gnu' '--prefix=/opt/zbox/run/php' '--sysconfdir=/opt/zbox/etc/php' '--includedir=/opt/zbox/include' '--with-config-file-path=/opt/zbox/etc/php' '--with-config-file-scan-dir=/opt/zbox/etc/php/conf.d' '--with-apxs2=/opt/zbox/run/apache/bin/apxs' '--enable-mbstring' '--with-zip' '--with-ffi' '--enable-bcmath' '--enable-pcntl' '--enable-ftp' '--enable-exif' '--enable-calendar' '--with-imap' '--with-imap-ssl' '--with-libdir=lib64' '--with-gettext' '--enable-gd' '--with-freetype' '--with-jpeg' '--with-webp' '--with-zlib' '--with-libxml' '--with-openssl' '--with-curl' '--with-bz2' '--with-readline' '--with-ldap' '--with-ldap-sasl' '--with-mysqli' '--with-pdo-mysql' '--with-pear' '--without-sqlite3' '--without-pdo-sqlite' '--enable-opcache' '--enable-intl' '--with-kerberos' '--disable-cgi' '--disable-phpdbg' 'build_alias=aarch64-linux-gnu' 'PKG_CONFIG_PATH=/usr/local/lib64/pkgconfig/'"
#define PHP_ODBC_CFLAGS	""
#define PHP_ODBC_LFLAGS		""
#define PHP_ODBC_LIBS		""
#define PHP_ODBC_TYPE		""
#define PHP_OCI8_DIR			""
#define PHP_OCI8_ORACLE_VERSION		""
#define PHP_PROG_SENDMAIL	"/usr/sbin/sendmail"
#define PEAR_INSTALLDIR         "/opt/zbox/run/php/lib/php"
#define PHP_INCLUDE_PATH	".:/opt/zbox/run/php/lib/php"
#define PHP_EXTENSION_DIR       "/opt/zbox/run/php/lib/php/extensions/no-debug-non-zts-20210902"
#define PHP_PREFIX              "/opt/zbox/run/php"
#define PHP_BINDIR              "/opt/zbox/run/php/bin"
#define PHP_SBINDIR             "/opt/zbox/run/php/sbin"
#define PHP_MANDIR              "/opt/zbox/run/php/php/man"
#define PHP_LIBDIR              "/opt/zbox/run/php/lib/php"
#define PHP_DATADIR             "/opt/zbox/run/php/share/php"
#define PHP_SYSCONFDIR          "/opt/zbox/etc/php"
#define PHP_LOCALSTATEDIR       "/opt/zbox/run/php/var"
#define PHP_CONFIG_FILE_PATH    "/opt/zbox/etc/php"
#define PHP_CONFIG_FILE_SCAN_DIR    "/opt/zbox/etc/php/conf.d"
#define PHP_SHLIB_SUFFIX        "so"
#define PHP_SHLIB_EXT_PREFIX    ""

==> ZenTaoPMS-biz11.7-zbox_arm64.tar.gz: zbox/include/php/main/build-defs.h <==
/*
   +----------------------------------------------------------------------+
   | PHP Version 7                                                        |
   +----------------------------------------------------------------------+
   | Copyright (c) The PHP Group                                          |
   +----------------------------------------------------------------------+
   | This source file is subject to version 3.01 of the PHP license,      |
   | that is bundled with this package in the file LICENSE, and is        |
   | available through the world-wide-web at the following url:           |
   | http://www.php.net/license/3_01.txt                                  |
   | If you did not receive a copy of the PHP license and are unable to   |
   | obtain it through the world-wide-web, please send a note to          |
   | license@php.net so we can mail you a copy immediately.               |
   +----------------------------------------------------------------------+
   | Author: Stig Sæther Bakken <ssb@php.net>                             |
   +----------------------------------------------------------------------+
*/

#define CONFIGURE_COMMAND " './configure'  '--build=aarch64-linux-gnu' '--prefix=/opt/zbox/run/php' '--sysconfdir=/opt/zbox/etc/php' '--includedir=/opt/zbox/include' '--with-config-file-path=/opt/zbox/etc/php' '--with-config-file-scan-dir=/opt/zbox/etc/php/conf.d' '--with-apxs2=/opt/zbox/run/apache/bin/apxs' '--enable-mbstring' '--with-zip' '--with-ffi' '--enable-bcmath' '--enable-pcntl' '--enable-ftp' '--enable-exif' '--enable-calendar' '--with-imap' '--with-imap-ssl' '--with-libdir=lib64' '--with-gettext' '--enable-gd' '--with-freetype' '--with-jpeg' '--with-webp' '--with-zlib' '--with-libxml' '--with-openssl' '--with-curl' '--with-bz2' '--with-readline' '--with-ldap' '--with-ldap-sasl' '--with-mysqli' '--with-pdo-mysql' '--with-pear' '--without-sqlite3' '--without-pdo-sqlite' '--enable-opcache' '--enable-intl' '--with-kerberos' '--disable-cgi' '--disable-phpdbg' '--enable-inline-optimization' 'build_alias=aarch64-linux-gnu' 'PKG_CONFIG_PATH=/usr/local/lib64/pkgconfig/'"
#define PHP_ODBC_CFLAGS	""
#define PHP_ODBC_LFLAGS		""
#define PHP_ODBC_LIBS		""
#define PHP_ODBC_TYPE		""
#define PHP_OCI8_DIR			""
#define PHP_OCI8_ORACLE_VERSION		""
#define PHP_PROG_SENDMAIL	"/usr/sbin/sendmail"
#define PEAR_INSTALLDIR         "/opt/zbox/run/php/lib/php"
#define PHP_INCLUDE_PATH	".:/opt/zbox/run/php/lib/php"
#define PHP_EXTENSION_DIR       "/opt/zbox/run/php/lib/php/extensions/no-debug-non-zts-20190902"
#define PHP_PREFIX              "/opt/zbox/run/php"
#define PHP_BINDIR              "/opt/zbox/run/php/bin"
#define PHP_SBINDIR             "/opt/zbox/run/php/sbin"
#define PHP_MANDIR              "/opt/zbox/run/php/php/man"
#define PHP_LIBDIR              "/opt/zbox/run/php/lib/php"
#define PHP_DATADIR             "/opt/zbox/run/php/share/php"
#define PHP_SYSCONFDIR          "/opt/zbox/etc/php"
#define PHP_LOCALSTATEDIR       "/opt/zbox/run/php/var"
#define PHP_CONFIG_FILE_PATH    "/opt/zbox/etc/php"
#define PHP_CONFIG_FILE_SCAN_DIR    "/opt/zbox/etc/php/conf.d"
#define PHP_SHLIB_SUFFIX        "so"
#define PHP_SHLIB_EXT_PREFIX    ""
